pub struct AttributeStat {
pub consumed: AttributeFormCounts,
pub redundant: AttributeFormCounts,
pub emitted: AttributeFormCounts,
}Fields
consumed: AttributeFormCountsDeclarative and prefix forms removed from the AST.
redundant: AttributeFormCountsConsumed forms whose attribute effect did not produce emitted output.
For prefixes this includes both already-active outer prefixes and prefixes whose body overrides or otherwise carries the effect.
emitted: AttributeFormCountsCanonical declarative and prefix forms emitted for the attribute.