Enums
Functions
- bare_
command_ node - Creates a known command node with no arguments.
- delimiter_
slot - Creates a mandatory delimiter argument slot.
- dimension_
slot - Creates a mandatory dimension argument slot.
- infix_
prefix_ args - Creates the two mandatory content arguments used when converting an infix node to a prefix command.
- integer_
slot - Creates a mandatory integer argument slot.
- linebreak_
command_ node - Creates the parser-shaped linebreak command.
- mandatory_
content_ slot - Creates a mandatory content argument slot wrapping the subtree rooted at
node_id. - prefix_
command_ node - Creates a prefix
Node::Commandfrom a builtin command record and a list of argument slots. - star_
slot - Creates a star (boolean) argument slot, representing a
*modifier on a command.